@@ -1,6 +1,6 @@
 from os.path import dirname, join
 from .jsorc_settings import JsOrcSettings
-from .jsorc import State, JsOrc
+from .jsorc import JsOrc
 
 
 def get_ver():
@@ -11,7 +11,7 @@ def get_ver():
 __version__ = get_ver()
 __creator__ = "Jason Mars and friends"
 __url__ = "https://jaseci.org"
-__all__ = ["State", "JsOrc", "JsOrcSettings"]
+__all__ = ["JsOrc", "JsOrcSettings"]
 
 
 def load_standard():
@@ -31,6 +31,7 @@ def load_standard():
     import jaseci.actions.standard.elastic  # noqa
     import jaseci.actions.standard.url  # noqa
     import jaseci.actions.standard.stripe  # noqa
+    import jaseci.actions.standard.regex  # noqa
 
 
 load_standard()
