@@ -1,7 +1,7 @@
 import os
 from unittest import TestCase
 
-from jaseci.svc import MetaService
+from jaseci import JsOrc
 from jaseci.utils.utils import TestCaseHelper
 
 
@@ -10,11 +10,10 @@ class CoreTest(TestCaseHelper, TestCase):
 
     fixture_src = __file__
 
-    def setUp(self, run_svcs=False):
+    def setUp(self):
         super().setUp()
-        self.meta = MetaService(run_svcs=run_svcs)
-        self.smast = self.meta.build_super_master()
-        self.mast = self.meta.build_master(h=self.smast._h)
+        self.smast = JsOrc.super_master()
+        self.mast = JsOrc.master(h=self.smast._h)
 
     def tearDown(self):
         super().tearDown()
